==> igloo_0_1_3.zip: igloo_0_1_3/igloo/language/1/barnraiser_01/mag_view.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of Igloo
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'common.lang.php');




//section titles
$lang['hdr_search'] = 							"search";
$lang['hdr_action'] = 							"do";
$lang['hdr_blogs'] = 							"blogs";
$lang['hdr_subjects'] = 						"subjects";
$lang['hdr_polls'] = 							"polls";
$lang['hdr_library_items'] = 					"wiki pages";
$lang['hdr_schedule'] = 						"events and tasks";
$lang['hdr_sub_rss'] = 							"RSS feed";


//ERROR
$lang['err_no_blog'] = 							"Sorry, there are no blogs available.";
$lang['err_no_subjects'] = 						"Sorry, no discussions available.";
$lang['err_no_schedule_items'] = 				"Sorry, there are no schedule items available.";
$lang['err_no_polls'] = 						"Sorry, there are no polls available.";
$lang['err_no_library_items'] = 				"Sorry, there are no wiki pages available.";

//TXT
$lang['txt_magazine_name'] =					"splash"; //for breadcrumb
$lang['txt_allocation'] = 						"allocation";
$lang['txt_rss_help'] = 						"An RSS feed is available for this node. Please note, if you change your password you will need to recreate this feed. See the help group for more information on RSS.";
$lang['txt_public_rss_help'] = 					"An public RSS feed is available for this node. Please note, if you log in you can get a feed which contains non public content. See the help section for more information RSS.";

?>

==> igloo_0_1_6.zip: igloo_0_1_6/igloo/language/1/barnraiser_01/mag_view.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of Igloo
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'common.lang.php');


// headers
$lang['hdr_blogs'] = 							"blogs";
$lang['hdr_subjects'] = 						"subjects";
$lang['hdr_polls'] = 							"polls";
$lang['hdr_library_items'] = 					"wiki pages";
$lang['hdr_schedule'] = 						"events and tasks";


//ERROR
$lang['err_no_blog'] = 							"Sorry, there are no blogs available.";
$lang['err_no_subjects'] = 						"Sorry, no discussions available.";
$lang['err_no_schedule_items'] = 				"Sorry, there are no schedule items available.";
$lang['err_no_polls'] = 						"Sorry, there are no polls available.";
$lang['err_no_library_items'] = 				"Sorry, there are no wiki pages available.";

//TXT
$lang['txt_magazine_name'] =					"featured group items"; //for breadcrumb
$lang['txt_allocation'] = 						"allocation";

?>
